#!/bin/bash
set -ex

## This script runs from within the armhf pbuilder, since we cant yet
## force install of armhf click packages any other way

#needs RTM sources.list because apparmor needs to match what's on the phone.
if [ -f out/sources.list ];then
	cp out/sources.list /etc/apt/sources.list
	apt-key adv --keyserver keyserver.ubuntu.com --recv-keys E96F1B6D5810338B
fi


#need click and click-apparmor to  install/compile profilesapt-get update
apt-get dist-upgrade -y --force-yes
apt-get install -y --force-yes click click-apparmor apparmor apparmor-easyprof-ubuntu

#/custom/click is where we'll install the clicks, needs to be owned by user/group clickpkg
mkdir -p /custom/click
chown clickpkg:clickpkg /custom/click

#out is bindmounted from outside the pbuilder
cd out

#install all the clicks to /custom/click, then run aa-clickhook to copy profiles
for i in `ls *.click`;do
		click install --root=/custom/click --force-missing-framework --all-users --allow-unauthenticated $i
done
aa-clickhook

#get the apparmor manifests
mkdir -p /custom/lib/apparmor/clicks
cp -P /var/lib/apparmor/clicks/* /custom/lib/apparmor/clicks

#get the apparmor profiles
mkdir -p /custom/lib/apparmor/profiles/
cp /var/lib/apparmor/profiles/* /custom/lib/apparmor/profiles

#DEBUG Get versions of apparmor and apparmor-easyprof-ubuntu to ensure they match what's on the phone
echo `apt-cache policy apparmor-easyprof-ubuntu` > easyprof_version
echo `apt-cache policy apparmor` > apparmor_version
echo `apt-cache policy libapparmor-perl` > apparmor_version

#we will ship precompiled apparmor caches to improve first boot time, in /custom/cache/apparmor
mkdir -p /custom/cache/apparmor

#compile the profiles to within /custom
FEATURES=./features
/sbin/apparmor_parser -M ${FEATURES} -Q --write-cache --cache-loc=/custom/cache/apparmor/ `find /var/lib/apparmor/profiles/ -maxdepth 1 -type f -not -path '*/\.*'`

#make a tarball of /custom for use outside the pbuilder
tar zcvf custom.tgz /custom
